@@ -60,8 +60,9 @@ sub contextualize_message {
     elsif( my @details = ($str =~ /^([A-F0-9]{8,16}): (.*)$/) ) {
         $ctxt{rec_id} = $details[0];
         foreach my $kv ( split /, /, $details[1] ) {
-            my ($k,$v) = ($kv =~ /(\w+)=<?([^>]+)>?/);
-            $ctxt{$MAP{$k}} = $v if exists $MAP{$k};
+            if( my ($k,$v) = ($kv =~ /(\w+)=<?([^>]+)>?/) ) {
+                $ctxt{$MAP{$k}} = $v if exists $MAP{$k};
+            }
         }
     }
     else {
@@ -89,7 +90,7 @@ eris::log::context::postfix
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
